import FormComponent from "@/components/form/Form";
import {
  Button,
  FormControl,
  FormLabel,
  Modal,
  ModalBody,
  ModalCloseButton,
  ModalContent,
  ModalFooter,
  ModalHeader,
  ModalOverlay,
  Switch,
  useColorModeValue,
} from "@chakra-ui/react";
import { useRef, useState } from "react";
import prepareValidationSchema from "@/utils/validation-schema";
import { ProjectInterface } from "../types/type";
import { InputWrapper, ToogleWrapper } from "@/components/fields/Fields";
import { formFields } from "../variables/formFields";
import { useFormikContext } from 'formik';
import { ProjectFormInterface } from "@/types/project";

interface ProjectModalFormProps {
  isOpen: boolean;
  onClose: () => void;
  currentUser: ProjectFormInterface | null;
  handleSubmit: (values: any) => Promise<void>;
}

const ProjectModalForm: React.FC<ProjectModalFormProps> = ({
  isOpen,
  onClose,
  currentUser,
  handleSubmit,
}) => {
  const textColor = useColorModeValue("navy.700", "white");
  const formRef = useRef(null);
  const brandStars = useColorModeValue("brand.500", "brand.400");
  const formDetails = prepareValidationSchema(formFields);
  const { initialFormData, validationSchema } = formDetails;
  const initialValues = currentUser ? { ...currentUser } : initialFormData;
  
  const handleSubmitClick = () => {
    formRef?.current?.externalHandleSubmit();
};

  return (
    <Modal onClose={onClose} size="lg" isOpen={isOpen}>
      <ModalOverlay />
      <ModalContent>
        <ModalHeader>{currentUser ? "Edit" : "Create"} Project</ModalHeader>
        <ModalCloseButton />
        <ModalBody>
          <FormComponent
            ref={formRef}
            validationSchema={validationSchema}
            initialValues={initialValues}
            submitForm={handleSubmit}
          >
            <FormControl w="full">
              <FormLabel fontSize="sm" fontWeight="500" color={textColor} mb="8px">
                Name
              </FormLabel>
              <InputWrapper 
                fieldName="name"
                defaultValue={currentUser?.name}
                id="area_name"
                variant="auth"
                w="full"
                mb="2px"
                fontSize="sm"
                type="text"
                fontWeight="500"
              />
            </FormControl>
            <FormControl w="full">
              <FormLabel fontSize="sm" fontWeight="500" color={textColor} mb="8px">
                Description
              </FormLabel>
              <InputWrapper 
                form
                fieldName="description"
                defaultValue={currentUser?.description}
                id="description"
                variant="auth"
                w="full"
                mb="2px"
                fontSize="sm"
                type="text"
                fontWeight="500"
              />
            </FormControl>
            <FormControl display="flex" alignItems="center" mt={4}>
              <FormLabel fontSize="sm" fontWeight="500" color={textColor} mb="8px">
                Kyc-Enable
              </FormLabel>
              <ToogleWrapper
                form={true}
                fieldName="kyc_form"
                id="kyc_form"
                variant="auth"
                w="full"
                mb="2px"
                fontSize="sm"
                type="text"
                fontWeight="500"
                defaultChecked={initialValues?.dc_form ?? "0"}
              />
            </FormControl>
            <FormControl display="flex" alignItems="center" mt={4}>
              <FormLabel fontSize="sm" fontWeight="500" color={textColor} mb="8px">
                Consumer-Enable
              </FormLabel>
              <ToogleWrapper
                form={true}
                fieldName="consumer_form"
                id="consumer_form"
                variant="auth"
                w="full"
                mb="2px"
                fontSize="sm"
                type="text"
                fontWeight="500"
                defaultChecked={initialValues?.dc_form ?? "0"}
              />
            </FormControl>
            <FormControl display="flex" alignItems="center" mt={4}>
              <FormLabel fontSize="sm" fontWeight="500" color={textColor} mb="8px">
                DC-Form
              </FormLabel>
              <ToogleWrapper
                form={true}
                fieldName="dc_form"
                id="dc_form"
                variant="auth"
                w="full"
                mb="2px"
                fontSize="sm"
                type="text"
                fontWeight="500"
                defaultChecked={initialValues?.dc_form ?? "0"}
              />
            </FormControl>
          </FormComponent>
        </ModalBody>
        <ModalFooter>
          <Button colorScheme="blue" onClick={handleSubmitClick} mr={3}>
            {currentUser ? "Save" : "Create"}
          </Button>
          <Button onClick={onClose} ml={3}>
            Cancel
          </Button>
        </ModalFooter>
      </ModalContent>
    </Modal>
  );
};

export default ProjectModalForm;